"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const sfpowerkit_1 = require("../../../../sfpowerkit");
const passwordgenerateimpl_1 = __importDefault(require("../../../../impl/user/passwordgenerateimpl"));
const core_1 = require("@salesforce/core");
class Generate extends command_1.SfdxCommand {
    async run() {
        sfpowerkit_1.SFPowerkit.setLogLevel(this.flags.loglevel, this.flags.json);
        //Connect to the org
        await this.org.refreshAuth();
        const conn = this.org.getConnection();
        let result = await passwordgenerateimpl_1.default.run(conn);
        if (!result.password) {
            throw new core_1.SfdxError(`Error occured unable to set password at the moment, please try later.`);
        }
        sfpowerkit_1.SFPowerkit.log(`Password successfully set for ${result.username} : ${result.password}`, sfpowerkit_1.LoggerLevel.INFO);
        return result;
    }
}
exports.default = Generate;
Generate.description = "Generates password for a given user in a salesforce org.";
Generate.examples = [
    `$ sfdx sfpowerkit:user:password:generate -u sandbox1`,
];
Generate.flagsConfig = {
    loglevel: command_1.flags.enum({
        description: "logging level for this command invocation",
        default: "info",
        required: false,
        options: [
            "trace",
            "debug",
            "info",
            "warn",
            "error",
            "fatal",
            "TRACE",
            "DEBUG",
            "INFO",
            "WARN",
            "ERROR",
            "FATAL",
        ],
    }),
};
// Comment this out if your command does not require a hub org username
Generate.requiresUsername = true;
//# sourceMappingURL=generate.js.map